@@ -181,7 +181,8 @@ class Transform:
                     "file_size": "Unknown",
                     "word_count": "Unknown",
                     "reading_time": "Unknown",
-                    "page_count": "Unknown"
+                    "page_count": "Unknown",
+                    "content_type": "Unknown"
 
                 }
             else:
